from django.forms.widgets import CheckboxSelectMultiple, ClearableFileInput
from bootstrap3_datetime.widgets import DateTimePicker as DateTimePickerOrigin
import os

__all__ = ["LabelWithDescription", "DescriptedCheckboxSelectMultiple", "DateTimePicker", "CustomFieldFile"]


class LabelWithDescription(object):
    def __init__(self, label, description):
        self.label = label
        self.description = description

    def __str__(self):
        return super(LabelWithDescription, self).__str__()


class DescriptedCheckboxSelectMultiple(CheckboxSelectMultiple):
    template_name = "guichet/forms/widgets/descripted_checkbox_select_multiple.html"


class DateTimePicker(DateTimePickerOrigin):
    class Media:
        css = {"all": ("css/bootstrap-datetimepicker.min.css",)}
        js = (
            "js/bootstrap-datetimepicker.moment.min.js",
            "js/locales/bootstrap-datetimepicker.fr.js",
            "js/bootstrap-datetimepicker.min.js",
        )


class ProxyFile(object):
    def __init__(self, label, url):
        self.label = label
        self.url = url

    def __str__(self):
        return self.label


class CustomFieldFile(ClearableFileInput):
    # this class permit to not display value.url

    def get_context(self, name, value, attrs):
        context = super(CustomFieldFile, self).get_context(name, value, attrs)
        if value and getattr(value, "url", False):
            context["widget"].update(
                {
                    "value": ProxyFile(label=os.path.basename(str(value)), url=value.url),
                }
            )
        return context
